/***************************************************************************
 *   Copyright (C) 2007 by Sébastien Laoût                                 *
 *   slaout@linux62.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef COVERDISPLAY_H
#define COVERDISPLAY_H

#include <qstringlist.h>
#include <qwidget.h>
#include <qpixmap.h>
#include <qimage.h>
#include <qtimer.h>
#include <qfont.h>

class ProgressBar;
class PlayerInformation;

/**
 * @author Sébastien Laoût <slaout@linux62.org>
 */
class CoverDisplay : public QWidget
{
  Q_OBJECT
  public:
	CoverDisplay(QWidget *parent);
	~CoverDisplay();

	int heightForWidth(int width);
	int widthForHeight(int height);
	void setFullScreen();
  signals:
	void updateLayout();
	void fullScreenAsked();
	void closeAsked();
  protected:
	QPixmap getAmarokImage(const QString &imageName);
	void loadButtonPixmaps(QPixmap icons[3], const QString &iconName, const QString &fallbackIconName, int width);
	void mouseMoveEvent(QMouseEvent *event);
	void enterEvent(QEvent *event);
	void leaveEvent(QEvent *event);
	void mousePressEvent(QMouseEvent *event);
	void mouseReleaseEvent(QMouseEvent *event);
	void wheelEvent(QWheelEvent *event);
	void paintEvent(QPaintEvent *event);
	void hideEvent(QHideEvent *event);
	void updateProgressBar();
	void computeButtonRects(int size);
	bool areControlsShown();
	void initPixmaps();
	bool eventFilter(QObject *object, QEvent *event);
  public slots:
	void hideControls();
  protected slots:
	void setPosition(int i);

	void updateCover();
	void updateStars();
	void updateButtons();
	void updateText();

	void newInformation();
	void newRating();
	void newProgress();

  private:
	bool m_underMouse;

	PlayerInformation *m_infos;

	int m_shadowX;
	int m_shadowWidth;

	QTimer  m_fullScreenTimer;
	int     m_hoveredStar;

	QImage  m_coverScalledImage;
	QImage  m_coverInvertedImage;

	QImage  m_starIcon;
	QImage  m_miniStarIcon;
	QImage  m_hoveredStarIcon;
	QImage  m_hoveredMiniStarIcon;
	QImage  m_hoveredEmptyStarIcon;
	QImage  m_hoveredHoveredEmptyStarIcon;

	QPixmap m_prevIcon[3];
	QPixmap m_nextIcon[3];
	QPixmap m_playIcon[3];
	QPixmap m_pauseIcon[3];
	QPixmap m_fullIcon[3];
	QPixmap m_closeIcon[3];

	QRect m_prevRect;
	QRect m_nextRect;
	QRect m_playRect;
	QRect m_fullRect;
	QRect m_closeRect;

	int m_hoveredButton;
	int m_clickedButton;

	QFont m_textFont;

	enum Orientation { Vertical, Horizontal, FullScreen };

	Orientation m_orientation;
	int         m_margin;
	int         m_progressMargin;
	int         m_buttonPadding;
	int         m_shadowMargin;
	int         m_starWidth;
	QRect       m_progressRect;
	QRect       m_coverRect;
	QRect       m_starsRect;
	QRect       m_textRect;

	ProgressBar *m_progressBar;
};

#endif // COVERDISPLAY_H
