/***************************************************************************
 *   Copyright (C) 2007 by Sébastien Laoût                                 *
 *   slaout@linux62.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "fullscreen.h"
#include "coverdisplay.h"
#include "amarokapi.h"

#include <qdesktopwidget.h>
#include <klocale.h>
#include <kapplication.h>
#include <kiconloader.h>
#include <kglobal.h>
#include <qimage.h>
#include <kimageeffect.h>
#include <kstandarddirs.h>

FullScreen::FullScreen(QWidget *parent, const char *name)
 : QWidget(parent, name)
{
	QDesktopWidget desktop;
	resize(desktop.size());

	setCaption(i18n("Kirocker Music Display"));
	setIcon(kapp->iconLoader()->loadIcon("kirocker", KIcon::Desktop, 48, KIcon::DefaultState));

	QImage backgroundImage(KGlobal::dirs()->findResource("data", "kirocker/images/colorwaves.jpg"));
	backgroundImage = backgroundImage.smoothScale(size());
	KImageEffect::blend(Qt::black, backgroundImage, 0.8);

	QPixmap backgroundPixmap;
	backgroundPixmap.convertFromImage(backgroundImage);

	m_coverDisplay = new CoverDisplay(this);
	m_coverDisplay->setGeometry(rect());
	m_coverDisplay->setBackgroundOrigin(QWidget::ParentOrigin);
	m_coverDisplay->setPaletteBackgroundColor(Qt::black);
	m_coverDisplay->setPaletteBackgroundPixmap(backgroundPixmap);
	m_coverDisplay->setFullScreen();
	m_coverDisplay->show();

	connect( m_coverDisplay, SIGNAL(closeAsked()), this, SLOT(close()) );
}

FullScreen::~FullScreen()
{
}

void FullScreen::keyPressEvent(QKeyEvent *event)
{
	switch (event->key()) {
		case Qt::Key_Space:
		case Qt::Key_Return: AmarokApi::playPause();     break;
		case Qt::Key_Left:   AmarokApi::previousTrack(); break;
		case Qt::Key_Right:  AmarokApi::nextTrack();     break;
		case Qt::Key_Escape: close();                    break;
	}

	QWidget::keyPressEvent(event);
}

void FullScreen::windowActivationChange(bool oldActive)
{
	// Disable screensaver only when this fullscreen window is enabled:
	AmarokApi::enableScreensaver(!isActiveWindow());
	AmarokApi::enableOSD(!isActiveWindow());
	m_coverDisplay->hideControls();

	QWidget::windowActivationChange(oldActive);
}

#include "fullscreen.moc"
